# Python
__pycache__/
*.py[cod]
*$py.class
.Python
.venv/
venv/
ENV/
*.egg-info/
.eggs/
dist/
build/
*.so
.mypy_cache/
.ruff_cache/
.pytype/

# Node
**/node_modules/
.next/
dist/
.cache/
.npm/
.yarn/
.pnpm-store/

# IDE
.vscode/
.idea/
*.swp
*.swo
*~
.DS_Store

# Prism
.prism/

# Git
.git/
.gitignore
.gitattributes

# Environment
.env
.env.local
.env.*.local
*.local

# Testing
.pytest_cache/
.tox/
.nox/
coverage/
.coverage
htmlcov/

# Logs
*.log
logs/

# Documentation
docs/_build/
*.md

# Docker (avoid including compose override files)
docker-compose.override.yml
docker-compose.override.yaml
Dockerfile*
.dockerignore

# Misc
Makefile
*.bak
*.tmp
