# Workspace Configuration
# Generated by: prism devcontainer up
# Regenerate with: prism devcontainer up --name <workspace-name>

WORKSPACE_NAME={{ workspace_name }}
COMPOSE_PROJECT_NAME={{ workspace_name }}
DATABASE_NAME={{ database_name }}
