# Server Module Outputs
# Generated by Prism

output "server_id" {
  description = "Server ID"
  value       = hcloud_server.main.id
}

output "server_ip" {
  description = "Server public IPv4 address"
  value       = hcloud_server.main.ipv4_address
}

output "server_ipv6" {
  description = "Server public IPv6 address"
  value       = hcloud_server.main.ipv6_address
}

output "private_ip" {
  description = "Server private IP address"
  value       = hcloud_server_network.main.ip
}

output "floating_ip" {
  description = "Floating IP address (if enabled)"
  value       = var.enable_floating_ip ? hcloud_floating_ip.main[0].ip_address : null
}

output "server_status" {
  description = "Server status"
  value       = hcloud_server.main.status
}
