# Getting Started

This guide will help you get started with {{ project_name }}.

## Prerequisites

- Python 3.11 or higher
- pip or uv package manager

## Installation

```bash
pip install {{ project_name }}
```

## Quick Start

```python
# Example usage
from {{ project_name }} import main

main()
```

## Next Steps

- Read the [User Guide](../user-guide/index.md) for detailed usage instructions
- Check the [API Reference](../reference/index.md) for detailed API documentation
