# Traefik static configuration for Prism development
# This file is generated by Prism and used for the shared reverse proxy

api:
  dashboard: true
  insecure: true  # For local development only

entryPoints:
  web:
    address: ":80"

providers:
  docker:
    exposedByDefault: false
    network: prism_proxy_network
    watch: true
  file:
    filename: /etc/traefik/dynamic.yml
    watch: true

log:
  level: INFO

accessLog:
  filePath: "/var/log/traefik/access.log"
