/**
 * GraphQL fragment for {{ model_name }}.
 *
 * ⚠️ AUTO-GENERATED BY PRISM - DO NOT EDIT
 */

import { graphql } from '../gql';

export const {{ model_name }}Fragment = graphql(`
  fragment {{ model_name }}Fragment on {{ model_name }}Type {
{{ fields_str }}
  }
`);

export const {{ model_name }}Fields = `
{{ fields_str }}
`;
