"""SQLAlchemy model for {{ model_name }}.

⚠️ AUTO-GENERATED BY PRISM - DO NOT EDIT
"""

from __future__ import annotations

{{ imports }}


class {{ model_name }}({{ base_classes | join(", ") }}):
    """{{ description or (model_name + ' model.') }}"""

    __tablename__ = "{{ table_name }}"

{{ columns }}
{{ relationships }}
