import './App.css';

function App() {
  return (
    <div className="min-h-screen bg-nordic-50">
      <div className="flex items-center justify-center min-h-screen">
        <div className="text-center max-w-lg mx-auto px-4">
          <div className="w-20 h-20 bg-nordic-900 rounded-2xl flex items-center justify-center mx-auto mb-6 shadow-nordic-lg">
            <span className="text-white font-bold text-3xl">{{ project_initial }}</span>
          </div>
          <h1 className="text-3xl font-semibold text-nordic-900 mb-3">{{ project_title }}</h1>
          <p className="text-nordic-500 mb-6">
            Your application is ready to be built.
          </p>
          <div className="card p-6 text-left">
            <p className="text-sm text-nordic-600 mb-4">Get started by running:</p>
            <code className="block bg-nordic-100 text-nordic-800 px-4 py-3 rounded-nordic text-sm font-mono">
              prism generate
            </code>
          </div>
        </div>
      </div>
    </div>
  );
}

export default App;
