# Python
__pycache__/
*.py[cod]
*$py.class
.Python
*.so
.eggs/
*.egg-info/
.pytest_cache/
.coverage
htmlcov/
.mypy_cache/
.ruff_cache/

# Virtual environments
.venv/
venv/
ENV/

# IDEs
.idea/
.vscode/
*.swp
*.swo

# Environment
.env
.env.local

# Node
node_modules/
dist/
.cache/

# OS
.DS_Store
Thumbs.db

# Build
build/
*.egg
*.whl

# Alembic
alembic/versions/*.pyc
