# Server Module Variables
# Generated by Prism

variable "project_name" {
  description = "Project name"
  type        = string
}

variable "environment" {
  description = "Environment name (staging, production)"
  type        = string
}

variable "server_type" {
  description = "Hetzner server type"
  type        = string
}

variable "location" {
  description = "Hetzner datacenter location"
  type        = string
}

variable "ssh_key_ids" {
  description = "SSH key IDs for server access"
  type        = list(string)
}

variable "subnet_id" {
  description = "Subnet ID"
  type        = string
}

variable "firewall_ids" {
  description = "Firewall IDs to attach"
  type        = list(string)
}

variable "cloud_init_file" {
  description = "Cloud-init configuration content"
  type        = string
}

variable "enable_floating_ip" {
  description = "Whether to create and attach a floating IP"
  type        = bool
  default     = false
}

variable "labels" {
  description = "Labels to apply to resources"
  type        = map(string)
  default     = {}
}
