/**
 * UI State Hooks
 *
 * Hooks for managing UI state like modals, confirmations, toasts, and drawers.
 *
 * ⚠️ AUTO-GENERATED BY PRISM - DO NOT EDIT
 */

export { useModal } from './useModal';
export {
  useConfirmation,
  useConfirmationState,
  ConfirmationProvider,
  type ConfirmationDialogProps,
} from './useConfirmation';
export {
  useToast,
  useToastState,
  ToastProvider,
  type ToastContainerProps,
} from './useToast';
export { useDrawer } from './useDrawer';
