"""Middleware module for {{ project_name }}.

AUTO-GENERATED BY PRISM - DO NOT EDIT
"""

from {{ project_name }}.middleware.api_key import (
    APIKey,
    get_api_key,
    require_api_key,
)

__all__ = [
    "APIKey",
    "get_api_key",
    "require_api_key",
]
