/* Prisme Documentation Custom Styles */

/* Hero section styling */
.md-typeset h1 {
  font-weight: 700;
}

/* Code block improvements */
.md-typeset pre > code {
  font-size: 0.85em;
}

/* Grid card improvements */
.md-typeset .grid.cards > ul > li {
  border-radius: 8px;
  transition: transform 0.2s ease-in-out, box-shadow 0.2s ease-in-out;
}

.md-typeset .grid.cards > ul > li:hover {
  transform: translateY(-2px);
  box-shadow: 0 4px 12px rgba(0, 0, 0, 0.1);
}

/* Table styling */
.md-typeset table:not([class]) th {
  font-weight: 600;
  background-color: var(--md-default-fg-color--lightest);
}

/* Admonition tweaks */
.md-typeset .admonition {
  border-radius: 8px;
}

/* Navigation improvements */
.md-nav__link {
  font-size: 0.85rem;
}

/* Footer styling */
.md-footer-meta {
  background-color: var(--md-primary-fg-color);
}

/* Tagline styling */
.md-typeset blockquote:first-of-type {
  font-size: 1.2em;
  border-left-color: var(--md-primary-fg-color);
  font-style: italic;
}
