/**
 * Form component for {{ model_name }}.
 *
 * ✅ YOUR CODE - Safe to modify, will not be overwritten.
 * This file was generated once by Prism and is yours to customize.
 */

import React from 'react';
import { {{ model_name }}FormBase, type {{ model_name }}FormBaseProps } from '../_generated/{{ model_name }}FormBase';
import { WidgetProvider } from '../../prism/widgets';

// Import custom widgets if needed
// import { CustomEmailWidget } from '../widgets/CustomEmailWidget';

interface {{ model_name }}FormProps extends {{ model_name }}FormBaseProps {
  // Add your custom props here
}

/**
 * {{ model_name }} form component.
 *
 * Customize this component to add:
 * - Custom widget overrides
 * - Additional form fields
 * - Custom validation
 * - Side effects
 */
export function {{ model_name }}Form(props: {{ model_name }}FormProps): JSX.Element {
  return (
    <WidgetProvider
      widgets={{ "{" }}{
        // Override widgets for this form
        // '{{ model_name }}.email': CustomEmailWidget,
      {{ "}}" }}
    >
      <div className="{{ kebab_name }}-form-wrapper">
        <{{ model_name }}FormBase {...props} />
        {/* Add custom content here */}
      </div>
    </WidgetProvider>
  );
}

export default {{ model_name }}Form;
