"""Pydantic schemas for {{ model_name }}.

⚠️ AUTO-GENERATED BY PRISM - DO NOT EDIT
"""

from __future__ import annotations

{{ imports }}


{{ base_schema }}


{{ create_schema }}


{{ update_schema }}


{{ read_schema }}


{{ filter_schema }}
{%- if nested_schema %}


{{ nested_schema }}
{%- endif %}
{%- if conditional_validators %}


{{ conditional_validators }}
{%- endif %}
