site_name: {{ project_title }}
site_description: {{ description }}

theme:
  name: {{ theme }}
  features:
    - navigation.tabs
    - navigation.sections
    - navigation.expand
    - navigation.top
    - search.suggest
    - search.highlight
    - content.code.copy
    - content.code.annotate
  palette:
    - scheme: default
      primary: indigo
      accent: indigo
      toggle:
        icon: material/brightness-7
        name: Switch to dark mode
    - scheme: slate
      primary: indigo
      accent: indigo
      toggle:
        icon: material/brightness-4
        name: Switch to light mode

nav:
  - Home: index.md
  - Getting Started:
      - getting-started/index.md
  - User Guide:
      - user-guide/index.md
  - Reference:
      - reference/index.md

plugins:
  - search
{% if include_api_docs %}
  - mkdocstrings:
      handlers:
        python:
          options:
            show_source: true
            show_root_heading: true
{% endif %}

markdown_extensions:
  - admonition
  - pymdownx.details
  - pymdownx.superfences
  - pymdownx.highlight:
      anchor_linenums: true
  - pymdownx.inlinehilite
  - pymdownx.snippets
  - pymdownx.tabbed:
      alternate_style: true
  - toc:
      permalink: true
  - attr_list
  - md_in_html
