"""Middleware module.

⚠️ AUTO-GENERATED BY PRISM - DO NOT EDIT
"""

from {{ project_name }}.middleware.auth import (
    CurrentActiveUser,
    CurrentUser,
    get_current_active_user,
    get_current_user,
    require_roles,
)

__all__ = [
    "CurrentActiveUser",
    "CurrentUser",
    "get_current_active_user",
    "get_current_user",
    "require_roles",
]
