/**
 * GraphQL operations index.
 *
 * ⚠️ AUTO-GENERATED BY PRISM - DO NOT EDIT
 */

export { client } from './client';
export { graphql, gql } from './gql';

{% for model in models %}
// {{ model.model_name }}
export * from './fragments/{{ model.snake_name }}';
export * from './queries/{{ model.snake_name }}';
{% if model.has_mutations %}
export * from './mutations/{{ model.snake_name }}';
{% endif %}
{% if model.has_subscriptions %}
export * from './subscriptions/{{ model.snake_name }}';
{% endif %}

{% endfor %}
